@@ -4,8 +4,10 @@
  *
  * Authors:
  *   Martin Baulig (baulig@suse.de)
+ *   Jens Finke (jens@triq.net)
  *
  * Copyright 2000 SuSE GmbH.
+ * Copyright 2001-2002 Free Software Foundation
  */
 
 #include <config.h>
@@ -47,7 +49,6 @@ struct _EogImageViewPrivate {
         ImageView             *image_view;
 
 	BonoboPropertyBag     *property_bag;
-	BonoboPropertyControl *property_control;
 
 	BonoboUIComponent     *uic;
 
@@ -73,6 +74,9 @@ enum {
 	PROP_CONTROL_TITLE
 };
 
+static BonoboControl* property_control_get_cb (BonoboPropertyControl *property_control,
+					       int page_number, void *closure);
+
 static guint eog_image_view_signals [LAST_SIGNAL];
 
 static GObjectClass *eog_image_view_parent_class;
@@ -1529,20 +1533,21 @@ eog_image_view_get_property_bag (EogImageView *image_view)
 	g_return_val_if_fail (image_view != NULL, NULL);
 	g_return_val_if_fail (EOG_IS_IMAGE_VIEW (image_view), NULL);
 
-	bonobo_object_ref (BONOBO_OBJECT (image_view->priv->property_bag));
-
 	return image_view->priv->property_bag;
 }
 
 BonoboPropertyControl *
 eog_image_view_get_property_control (EogImageView *image_view)
 {
+	BonoboEventSource *es;
+
 	g_return_val_if_fail (image_view != NULL, NULL);
 	g_return_val_if_fail (EOG_IS_IMAGE_VIEW (image_view), NULL);
 
-	bonobo_object_ref (BONOBO_OBJECT (image_view->priv->property_control));
+	es = bonobo_event_source_new ();
 
-	return image_view->priv->property_control;
+	return bonobo_property_control_new_full (property_control_get_cb, 
+						 1, es, image_view);
 }
 
 void
@@ -1800,12 +1805,9 @@ eog_image_view_destroy (BonoboObject *object)
 	image_view = EOG_IMAGE_VIEW (object);
 	priv = image_view->priv;
 
-	gtk_object_unref (GTK_OBJECT (priv->client));
+	g_object_unref (G_OBJECT (priv->client));
 
 	bonobo_object_unref (BONOBO_OBJECT (priv->property_bag));
-//BEWARE: After this has been added somewhere by bonobo_object_add_interface, 
-//        we don't own this anymore. Therefore, we cannot touch it. 
-//	bonobo_object_unref (BONOBO_OBJECT (priv->property_control));
 	bonobo_object_unref (BONOBO_OBJECT (priv->image));
 	bonobo_object_unref (BONOBO_OBJECT (priv->uic));
 
@@ -1988,13 +1990,7 @@ eog_image_view_construct (EogImageView       *image_view,
 				 BONOBO_ARG_STRING, NULL, _("Statusbar Text"),
 				 BONOBO_PROPERTY_READABLE);
 
-	/* Property Control */
-
-	image_view->priv->property_control = bonobo_property_control_new
-		(property_control_get_cb, 1, image_view);
-
 	/* UI Component */
-
 	image_view->priv->uic = bonobo_ui_component_new ("EogImageView");
 
 	return image_view;
